==> binnie-mods-1.12.1-2.3.0.34-sources.jar: binnie/core/network/packet/MessageSyncTile.java <==
package binnie.core.network.packet;

import javax.annotation.Nullable;
import java.io.IOException;

import net.minecraft.nbt.NBTTagCompound;
import net.minecraft.tileentity.TileEntity;
import net.minecraft.util.math.BlockPos;
import net.minecraft.world.World;

import io.netty.buffer.ByteBuf;

public class MessageSyncTile extends MessageNBT {
	private int posX;
	private int posY;
	private int posZ;

	public MessageSyncTile(final MessageBinnie message) {
		super(message);
	}

	public MessageSyncTile(final int id, final TileEntity tile, final NBTTagCompound nbt) {
		super(id);
		this.posX = tile.getPos().getX();
		this.posY = tile.getPos().getY();
		this.posZ = tile.getPos().getZ();
		this.nbt = nbt;
	}

	@Override
	public void writeData(final ByteBuf data) throws IOException {
		data.writeInt(this.posX);
		data.writeInt(this.posY);
		data.writeInt(this.posZ);
		super.writeData(data);
	}

	@Override
	public void readData(final ByteBuf data) throws IOException {
		this.posX = data.readInt();
		this.posY = data.readInt();
		this.posZ = data.readInt();
		super.readData(data);
	}

	@Nullable
	public TileEntity getTarget(final World world) {
		return world.getTileEntity(new BlockPos(this.posX, this.posY, this.posZ));
	}

	public int getX() {
		return this.posX;
	}

	public int getY() {
		return this.posY;
	}

	public int getZ() {
		return this.posZ;
	}

	@Override
	public NBTTagCompound getTagCompound() {
		return this.nbt;
	}

	@Override
	void setTagCompound(final NBTTagCompound nbt) {
		this.nbt = nbt;
	}
}

==> binnie-mods-1.12-2.2.0.3-sources.jar: binnie/core/network/packet/MessageSyncTile.java <==
package binnie.core.network.packet;

import javax.annotation.Nullable;
import java.io.IOException;

import net.minecraft.nbt.NBTTagCompound;
import net.minecraft.tileentity.TileEntity;
import net.minecraft.util.math.BlockPos;
import net.minecraft.world.World;

import io.netty.buffer.ByteBuf;

public class MessageSyncTile extends MessageNBT implements IPacketLocation {
	private int posX;
	private int posY;
	private int posZ;

	public MessageSyncTile(final MessageBinnie message) {
		super(message);
	}

	public MessageSyncTile(final int id, final TileEntity tile, final NBTTagCompound nbt) {
		super(id);
		this.posX = tile.func_174877_v().func_177958_n();
		this.posY = tile.func_174877_v().func_177956_o();
		this.posZ = tile.func_174877_v().func_177952_p();
		this.nbt = nbt;
	}

	@Override
	public void writeData(final ByteBuf data) throws IOException {
		data.writeInt(this.posX);
		data.writeInt(this.posY);
		data.writeInt(this.posZ);
		super.writeData(data);
	}

	@Override
	public void readData(final ByteBuf data) throws IOException {
		this.posX = data.readInt();
		this.posY = data.readInt();
		this.posZ = data.readInt();
		super.readData(data);
	}

	@Override
	@Nullable
	public TileEntity getTarget(final World world) {
		return world.func_175625_s(new BlockPos(this.posX, this.posY, this.posZ));
	}

	@Override
	public int getX() {
		return this.posX;
	}

	@Override
	public int getY() {
		return this.posY;
	}

	@Override
	public int getZ() {
		return this.posZ;
	}

	@Override
	public NBTTagCompound getTagCompound() {
		return this.nbt;
	}

	@Override
	void setTagCompound(final NBTTagCompound nbt) {
		this.nbt = nbt;
	}
}
